==> ZenTaoPMS.max2.0.rc1.php7.2.zip: zentaopms/module/host/view/m.browse.html.php <==
<?php include '../../common/view/m.header.html.php';?>
<section id='page' class='section list-with-actions list-with-pager'>
  <table class="table bordered">
    <thead>
    <tr>
      <?php $vars = "browseType=$browseType&param=$param&orderBy=%s&recTotal={$pager->recTotal}&recPerPage={$pager->recPerPage}";?>
      <th class='text-left'><?php common::printOrderLink('group',     $orderBy, $vars, $lang->host->group);?></th>
      <th class='text-left'><?php common::printOrderLink('name',      $orderBy, $vars, $lang->host->name);?></th>
      <th class='w-110px'>  <?php common::printOrderLink('privateIP', $orderBy, $vars, $lang->host->privateIP);?></th>
      <th class='w-70px'>   <?php common::printOrderLink('status',    $orderBy, $vars, $lang->host->status);?></th>
    </tr>
    </thead>
    <?php if(!empty($hostList)):?>
    <tbody>
    <?php foreach($hostList as $host):?>
    <tr class='text-left' data-url="<?php echo $this->inlink('view', "id=$host->id");?>">
      <td class='hidden-xs hidden-sm'><?php echo $optionMenu[$host->group];?></td>
      <td><?php echo $host->name;?></td>
      <td><?php echo $host->privateIP;?></td>
      <td class='hidden-xs hidden-sm'><?php echo $lang->host->statusList[$host->status];?></td>
    </tr>
    <?php endforeach;?>
    </tbody>
    <?php endif;?>
  </table>
  <?php if(!empty($hostList)):?>
  <nav class='nav justify pager'>
    <?php $pager->show($align = 'justify');?>
  </nav>
  <?php endif;?>
</section>
<?php include '../../common/view/m.footer.html.php';?>

==> ZenTaoPMS.max2.4.php7.2_7.4.zip: zentaopms/module/host/view/m.browse.html.php <==
<?php include '../../common/view/m.header.html.php';?>
<section id='page' class='section list-with-actions list-with-pager'>
  <table class="table bordered">
    <thead>
    <tr>
      <?php $vars = "browseType=$browseType&param=$param&orderBy=%s&recTotal={$pager->recTotal}&recPerPage={$pager->recPerPage}";?>
      <th class='text-left'><?php common::printOrderLink('group',     $orderBy, $vars, $lang->host->group);?></th>
      <th class='text-left'><?php common::printOrderLink('name',      $orderBy, $vars, $lang->host->name);?></th>
      <th class='w-110px'>  <?php common::printOrderLink('privateIP', $orderBy, $vars, $lang->host->privateIP);?></th>
      <th class='w-70px'>   <?php common::printOrderLink('status',    $orderBy, $vars, $lang->host->status);?></th>
    </tr>
    </thead>
    <?php if(!empty($hostList)):?>
    <tbody>
    <?php foreach($hostList as $host):?>
    <tr class='text-left' data-url="<?php echo $this->inlink('view', "id=$host->id");?>">
      <td class='hidden-xs hidden-sm'><?php echo zget($optionMenu, $host->group, '');?></td>
      <td><?php echo $host->name;?></td>
      <td><?php echo $host->privateIP;?></td>
      <td class='hidden-xs hidden-sm'><?php echo $lang->host->statusList[$host->status];?></td>
    </tr>
    <?php endforeach;?>
    </tbody>
    <?php endif;?>
  </table>
  <?php if(!empty($hostList)):?>
  <nav class='nav justify pager'>
    <?php $pager->show($align = 'justify');?>
  </nav>
  <?php endif;?>
</section>
<?php include '../../common/view/m.footer.html.php';?>
